package Plugins::InfoBrowserAddons::SlimForums::ForumArchive;

use strict;

use Slim::Formats::XML;
use HTML::Parser;

# Example HTML parser - this parses the Archive pages from vBulletin and returns information an a hash understood by xmlbrowser.

sub parse {
	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url    = $params->{'url'};

	my ($username, $date, $time, $body, $title);
	my ($expectTitle, $expectUsername, $expectDate, $expectPostText);

	my @posts;
	my $breaks = 0;

	my $p = HTML::Parser->new(api_version => 3,
		start_h => [
			sub {
				my $tag  = shift;
				my $attr = shift;

				if ($tag eq 'title') { $expectTitle = 1; }

				if ($tag eq 'div' && exists $attr->{'class'}) {
					my $class = $attr->{'class'};
					if ($class eq 'username') { $expectUsername = 1; }
					if ($class eq 'date')     { $expectDate = 1;     }
					if ($class eq 'posttext') { $expectPostText = 1; }
				}

				if (($tag eq 'hr' || $tag eq 'br') && $breaks < 1) {
					$body .= "\n";
					$breaks++;
				}

			}, "tagname,attr"
		],
		text_h => [
			sub {
				my $text = shift;

				if ($expectTitle) {
					$title = $text;
					($title) = $title =~ /(.*)\[Archive\]/;
					$expectTitle = 0;
				}
				if ($expectUsername) {
					$username = $text;
				}
				if ($expectDate) {
					($date, $time) = $text =~ /(\d+\-\d+-\d+), (\d+:\d+)/;
				}
				if ($expectPostText) {
					$body .= $text;
				}
			}, "text"
		],
		end_h => [
			sub {
				my $tag = shift;

				if ($body && $expectPostText) {
					push @posts, {
						'name'        => $username,
						'description' => Slim::Formats::XML::unescape($body),
					};
				}

				$expectUsername = $expectDate = $expectPostText = 0;
				$body = '';
				$breaks = 0;
			}, "tagname"
		],
	);

	$p->parse(${$http->contentRef});

	my $i = 1;

	for my $post (@posts) {
		$post->{'name'}  = "#$i - " . $post->{'name'};
		$post->{'title'} = $post->{'name'};
		$i++;
	}

	my $ret = {
		'type'  => 'opml',
		'title' => $title,
		'items' => \@posts,
	};

	return $ret;
}

1;
